<?php
/**
 * Test combining partial free/busy scripts into a single vCalendar.
 *
 * PHP version 5
 *
 * @category   Kolab
 * @package    Kolab_FreeBusy
 * @subpackage UnitTests
 * @author     Gunnar Wrobel <wrobel@pardus.de>
 * @license    http://www.fsf.org/copyleft/lgpl.html LGPL
 * @link       http://pear.horde.org/index.php?package=Kolab_FreeBusy
 */

/**
 * Prepare the test setup.
 */
require_once dirname(__FILE__) . '/../../../../../Autoload.php';

/**
 * Test combining partial free/busy scripts into a single vCalendar.
 *
 * Copyright 2010 Klarälvdalens Datakonsult AB
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
 *
 * @category   Kolab
 * @package    Kolab_FreeBusy
 * @subpackage UnitTests
 * @author     Gunnar Wrobel <wrobel@pardus.de>
 * @license    http://www.fsf.org/copyleft/lgpl.html LGPL
 * @link       http://pear.horde.org/index.php?package=Kolab_FreeBusy
 */
class Horde_Kolab_FreeBusy_Class_Export_Freebusy_Combined_Decorator_CacheTest
extends PHPUnit_Framework_TestCase
{
    public function setUp()
    {
        global $conf;

        $this->cache_dir = Horde::getTempDir() . '/Kolab_FreeBusy_Test_' . md5(uniqid(mt_rand(), true));

        $this->xaclcache = new Horde_Kolab_FreeBusy_Stub_Xacl(array('test' => array('group@example.org')));
        $this->aclcache = $this->getMock('Horde_Kolab_FreeBusy_Cache_Db_Acl', array('get'), array(), '', false, false);
        $this->xaclfilecache = $this->getMock('Horde_Kolab_FreeBusy_Cache_File_Xacl', array(), array(), '', false, false);
        $this->aclfilecache = $this->getMock('Horde_Kolab_FreeBusy_Cache_File_Acl', array(), array(), '', false, false);

        $this->stubstructure = new Horde_Kolab_FreeBusy_Stub_Structure(
                $this->cache_dir
        );
        $this->stubstructure->setAclDbCache($this->aclcache);
        $this->stubstructure->setXaclDbCache($this->xaclcache);
        $this->structure = new Horde_Kolab_FreeBusy_Cache_Structure_Decorator_Log(
            $this->stubstructure,
            new Horde_Kolab_FreeBusy_Logger()
        );

        $this->user = new Horde_Kolab_FreeBusy_Stub_User(array());

        $this->owner = $this->getMock('Horde_Kolab_FreeBusy_Owner', array('getPrimaryId', 'getName', 'getMail'), array(), '', false, false);
        $this->owner->expects($this->any())
            ->method('getName')
            ->will($this->returnValue('Mr. Test'));
        $this->owner->expects($this->any())
            ->method('getPrimaryId')
            ->will($this->returnValue('test@example.org'));

        $this->combined = new Horde_Kolab_FreeBusy_Export_Freebusy_Combined(
            $this->owner, $this->structure->getCombined($this->owner, $this->user, $this->structure)
        );

        $this->cache = new Horde_Kolab_FreeBusy_Export_Freebusy_Combined_Decorator_Cache(
            $this->combined, $this->owner, $this->user, $this->cache_dir
        );

        $conf = array();
        $conf['log']['enabled'] = true;
        $conf['log']['type'] = 'null';
        $conf['log']['name'] = 'mock';
        $conf['log']['ident'] = 'mock';
        $conf['log']['params'] = array();
        $conf['log']['priority'] = PEAR_LOG_DEBUG;
        $log = Horde::getLogger();
    }

    public function testMethodGetsignature()
    {
        global $conf;

        $conf['fb']['vcal_cache']['min_age'] = -1;

        $vfb = $this->cache->generate(true)->findComponent('vfreebusy');
        $this->assertEquals(
            array(array('cn' => 'Mr. Test')),
            $vfb->getAttribute('ORGANIZER', true)
        );

        $this->user = new Horde_Kolab_FreeBusy_Stub_User(array('group@example.org'));

        $vfb = $this->cache->generate(true)->findComponent('vfreebusy');
        $this->assertEquals(
            array(array('cn' => 'Mr. Test')),
            $vfb->getAttribute('ORGANIZER', true)
        );
    }
}
