<?php
/**
 * Test combining partial free/busy scripts into a single vCalendar.
 *
 * PHP version 5
 *
 * @category   Kolab
 * @package    Kolab_FreeBusy
 * @subpackage UnitTests
 * @author     Gunnar Wrobel <wrobel@pardus.de>
 * @license    http://www.fsf.org/copyleft/lgpl.html LGPL
 * @link       http://pear.horde.org/index.php?package=Kolab_FreeBusy
 */

/**
 * Prepare the test setup.
 */
require_once dirname(__FILE__) . '/../../../Autoload.php';

/**
 * Test combining partial free/busy scripts into a single vCalendar.
 *
 * Copyright 2010 Klarälvdalens Datakonsult AB
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
 *
 * @category   Kolab
 * @package    Kolab_FreeBusy
 * @subpackage UnitTests
 * @author     Gunnar Wrobel <wrobel@pardus.de>
 * @license    http://www.fsf.org/copyleft/lgpl.html LGPL
 * @link       http://pear.horde.org/index.php?package=Kolab_FreeBusy
 */
class Horde_Kolab_FreeBusy_Class_Export_Freebusy_CombinedTest
extends PHPUnit_Framework_TestCase
{
    public function setUp()
    {
        global $conf;

        $this->cache_dir = Horde::getTempDir() . '/Kolab_FreeBusy_Test_' . md5(uniqid(mt_rand(), true));

        $this->xaclcache = $this->getMock('Horde_Kolab_FreeBusy_Cache_Db_Xacl', array(), array(), '', false, false);
        $this->aclcache = $this->getMock('Horde_Kolab_FreeBusy_Cache_Db_Acl', array('get'), array(), '', false, false);
        $this->xaclfilecache = $this->getMock('Horde_Kolab_FreeBusy_Cache_File_Xacl', array(), array(), '', false, false);
        $this->aclfilecache = $this->getMock('Horde_Kolab_FreeBusy_Cache_File_Acl', array(), array(), '', false, false);

        $this->stubstructure = new Horde_Kolab_FreeBusy_Stub_Structure(
                $this->cache_dir
        );
        $this->stubstructure->setAclDbCache($this->aclcache);
        $this->stubstructure->setXaclDbCache($this->xaclcache);
        $this->structure = new Horde_Kolab_FreeBusy_Cache_Structure_Decorator_Log(
            $this->stubstructure,
            new Horde_Kolab_FreeBusy_Logger()
        );

        $this->user = $this->getMock('Horde_Kolab_FreeBusy_User', array('getPrimaryId', 'getGroupAddresses', 'getDomain', 'isAuthenticated'), array(), '', false, false);
        $this->user->expects($this->any())
            ->method('getGroupAddresses')
            ->will($this->returnValue(array()));
        $this->user->expects($this->any())
            ->method('getPrimaryId')
            ->will($this->returnValue('anonymous@example.org'));

        $this->owner = $this->getMock('Horde_Kolab_FreeBusy_Owner', array('getPrimaryId', 'getName', 'getMail'), array(), '', false, false);
        $this->owner->expects($this->any())
            ->method('getName')
            ->will($this->returnValue('Mr. Test'));
        $this->owner->expects($this->any())
            ->method('getPrimaryId')
            ->will($this->returnValue('test@example.org'));

        $this->combined = new Horde_Kolab_FreeBusy_Export_Freebusy_Combined(
            $this->owner, $this->structure->getCombined($this->owner, $this->user, $this->structure)
        );

        $conf = array();
        $conf['log']['enabled'] = true;
        $conf['log']['type'] = 'null';
        $conf['log']['name'] = 'mock';
        $conf['log']['ident'] = 'mock';
        $conf['log']['params'] = array();
        $conf['log']['priority'] = PEAR_LOG_DEBUG;
        $conf['fb']['use_acls'] = true;
        $log = Horde::getLogger();
        $this->observer = new Horde_Kolab_FreeBusy_Stub_Observer(PEAR_LOG_DEBUG);
        $log->attach($this->observer);
    }

    public function testMethodGenerateDeliversEmptyVcalendarIfNoPartialsWereGiven()
    {
        $this->aclcache->expects($this->once())
            ->method('get')
            ->will($this->returnValue(array()));

        $result = $this->combined->generate();
        $result = $result[0]->exportvCalendar();
        $vcal = new Horde_iCalendar();
        $result = $vcal->parsevCalendar($result);
        $vfb = $vcal->findComponent('vfreebusy');

        $this->assertEquals(
            'This is a dummy vfreebusy that indicates an empty calendar',
            $vfb->getAttribute('COMMENT')
        );
    }

    public function testMethodGenerateLoadsExtendedPartialDataIfRequestedAndAllowed()
    {
        $this->aclcache->expects($this->any())
            ->method('get')
            ->with('test@example.org')
            ->will($this->returnValue(array('test')));

        $this->xaclcache->expects($this->once())
            ->method('has')
            ->with('test', 'anonymous@example.org')
            ->will($this->returnValue(true));

        $this->combined->generate(true);
    }

    public function testMethodGenerateDoesNotLoadExtendedPartialDataIfRequestedAndDisallowed()
    {
        $this->aclcache->expects($this->any())
            ->method('get')
            ->with('test@example.org')
            ->will($this->returnValue(array('test')));

        $this->xaclcache->expects($this->once())
            ->method('has')
            ->with('test', 'anonymous@example.org')
            ->will($this->returnValue(false));

        $this->combined->generate(true);
    }

    public function testMethodGenerateLogsExtendedAclResultIfExtendedDataWasRequestedAndCurrentUserIsAnonymous()
    {
        $this->aclcache->expects($this->any())
            ->method('get')
            ->with('test@example.org')
            ->will($this->returnValue(array('test')));

        $this->access->user_object = null;

        $this->combined->generate(true);

        $this->assertContains(
            'Extended attributes on file test disallowed for user "anonymous@example.org".',
            $this->observer->events[0]['message']
        );
    }

    public function testMethodGenerateLogsExtendedAclResultIfExtendedDataWasRequestedAndDenied()
    {
        $this->aclcache->expects($this->any())
            ->method('get')
            ->with('test@example.org')
            ->will($this->returnValue(array('test')));

        $this->xaclcache->expects($this->once())
            ->method('has')
            ->with('test', 'anonymous@example.org')
            ->will($this->returnValue(false));

        $this->combined->generate(true);

        $this->assertContains(
            'Extended attributes on file test disallowed for user "anonymous@example.org".',
            $this->observer->events[0]['message']
        );
    }

    public function testMethodGetsignature()
    {
        $this->aclcache->expects($this->any())
            ->method('get')
            ->with('test@example.org')
            ->will($this->returnValue(array('test')));

        $this->xaclcache->expects($this->once())
            ->method('has')
            ->with('test', 'anonymous@example.org')
            ->will($this->returnValue(true));

        $this->assertEquals(
            '3d32c86e0a0c19ecd9da963732365dd9',
            $this->combined->getSignature(true)
        );
    }
}
